#
# spec file for package mISDNuser
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mISDNuser
Version:        2.1.0+2.0.22+git6
Release:        2.8
Summary:        Tools and library for mISDN
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          Hardware/ISDN
URL:            https://github.com/ISDN4Linux/mISDNuser

Source:         %name-%version.tar.xz
Source8:        %name-rpmlintrc
Patch0:         mISDNuser-fix-gcc10.patch
BuildRequires:  autoconf >= 2.63
BuildRequires:  automake
BuildRequires:  flex
BuildRequires:  libcapi20-devel
BuildRequires:  libtool >= 2
BuildRequires:  xz

%description
This package contains libmisdn and some tools to use the mISDN driver.
mISDN is the new modular ISDN driver for Linux.

%package -n libmisdn1
Summary:        mISDN core library
Group:          System/Libraries

%description -n libmisdn1
The mISDN core library.

%package devel
Summary:        C header files for mISDN
Group:          Development/Libraries/C and C++
Requires:       libmisdn1 = %version

%description devel
This package contain the header files and libraries for
mISDNuser development.

%package -n libcapi20-mod_misdn
Summary:        mISDN plugin for libcapi
Group:          Development/Libraries/C and C++
Requires:       capi4linux

%description -n libcapi20-mod_misdn
This package contain the CAPI 2.0 module for mISDN.

%prep
%setup
%if 0%{?suse_version} > 1500
%patch0 -p1
%endif

%build
if [ ! -e configure ]; then
	mkdir -p m4
	autoreconf -fi
fi
export CFLAGS="%optflags -Wno-error"
export CXXFLAGS="$CFLAGS"
%configure \
  --disable-static \
  --enable-capi
%make_build

%install
%make_install
b="%buildroot"
find "$b/%_libdir" -type f -name "*.la" -delete
mkdir -p "$b/%_prefix/lib/udev/rules.d"
mv "$b/etc/udev/rules.d"/* "$b/%_prefix/lib/udev/rules.d/"

%post   -n libmisdn1 -p /sbin/ldconfig
%postun -n libmisdn1 -p /sbin/ldconfig

%files
%license COPYING.LIB LICENSE
%doc AUTHORS NEWS README
%doc capi20/capi20.conf.sample
%doc tools/misdnlogger.conf.sample

%_sysconfdir/misdn*conf
%_bindir/*
%_sbindir/*
%_prefix/lib/udev/

%files -n libcapi20-mod_misdn
%exclude %_sysconfdir/capi20.conf
%dir %_libdir/capi
%_libdir/capi/lib_capi_mod_misdn.so*

%files -n libmisdn1
%_libdir/libmisdn.so.1*

%files devel
%_includedir/mISDN/
%_libdir/*.so

%changelog
* Sun Apr 10 2022 Martin Hauke <mardnh@gmx.de>
- Build with support for CAPI
- Add patch:
  * mISDNuser-fix-gcc10.patch
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new snapshot 2.1.0+2.0.22+git6 (d6818dd9a)
  * mISDNcapid: Add experimental partial early B3 support.
  * mISDNcapid: Parse B channel id first from message then its
    included IEs.
  * Add LLC logging
  * Create signal handler for capi20: SIGHUP re-opens debug log file.
  * Fix possible buffer overflows detected by newer GCC versions.
* Wed Jun  7 2017 jengelh@inai.de
- Build with -Wno-error to fix a build failure on Tumbleweed
  caused by duplicate but harmless const keywords "const const T".
- Update to upstream release 2.1.0
  * Fix memory leak on read() error.
  * Parse channel information from CALL PROCEEDING message too
    in mISDNcapid.
  * Use Reject parameter for deciding what happens to call via
    CONNECT_B3_RESP.
  * Fix CAPI-initiated disconnection in direct layer 1 mode.
  * mISDNcapid: Add hint for the -d --debug parameter in
    help output.
* Sun Mar  1 2015 p.drouand@gmail.com
- Update to version 2.0.19
  * no changelog available
- Re-enable Werror (fixes on upstream release)
- Remove 0001-Fix-compile-error-with-newer-gcc-and-a-reaL-BUG.patch
  merged on upstream release
* Tue Dec 24 2013 jengelh@inai.de
- Disable -Werror during compilation
* Mon Jun 24 2013 jengelh@inai.de
- Add 0001-Fix-compile-error-with-newer-gcc-and-a-reaL-BUG.patch
* Thu Nov 29 2012 cfarrell@suse.com
- license update: GPL-2.0 and LGPL-2.1
  Semicolon is ambiguous. Use ^and^ or ^or^ depending on the interaction
* Thu Nov 15 2012 jengelh@inai.de
- Update to new upstream release 2.0.17
  * no upstream changelog provided
- Delete misdn-fixes.diff, merged upstream
* Sun Oct  9 2011 jengelh@medozas.de
- Update to mISDNuser-2.0.2
  * new userspace API, uses sockets to communicate with kernel
  * layer3 (TE/NT) is done in userspace now
  * Q.931/DSS1 support for TE/NT
  * note: Asterisk integration occurs via chan_lcr
- Employ shlib policy
- Remove redundant/obsolete tags/sections (cf. specfile guidelines)
* Fri Jun  4 2010 cristian.rodriguez@opensuse.org
- do not fail when selinux is running
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Mon Sep  1 2008 kkeil@suse.de
-  first version
